==> ibus-qt_1.3.0-1maemo2.tar.gz: ibus-qt-1.3.0/qtim/cmake_install.cmake <==
# Install script for directory: /home/takahiro/devel/kenya888s-maemocjk/kenya888s-maemocjk/ibus-qt-1.3.0-maemo/qtim

# Set the install prefix
IF(NOT DEFINED CMAKE_INSTALL_PREFIX)
  SET(CMAKE_INSTALL_PREFIX "/opt/maemocjk2/usr")
ENDIF(NOT DEFINED CMAKE_INSTALL_PREFIX)
STRING(REGEX REPLACE "/$" "" CMAKE_INSTALL_PREFIX "${CMAKE_INSTALL_PREFIX}")

# Set the install configuration name.
IF(NOT DEFINED CMAKE_INSTALL_CONFIG_NAME)
  IF(BUILD_TYPE)
    STRING(REGEX REPLACE "^[^A-Za-z0-9_]+" ""
           CMAKE_INSTALL_CONFIG_NAME "${BUILD_TYPE}")
  ELSE(BUILD_TYPE)
    SET(CMAKE_INSTALL_CONFIG_NAME "")
  ENDIF(BUILD_TYPE)
  MESSAGE(STATUS "Install configuration: \"${CMAKE_INSTALL_CONFIG_NAME}\"")
ENDIF(NOT DEFINED CMAKE_INSTALL_CONFIG_NAME)

# Set the component getting installed.
IF(NOT CMAKE_INSTALL_COMPONENT)
  IF(COMPONENT)
    MESSAGE(STATUS "Install component: \"${COMPONENT}\"")
    SET(CMAKE_INSTALL_COMPONENT "${COMPONENT}")
  ELSE(COMPONENT)
    SET(CMAKE_INSTALL_COMPONENT)
  ENDIF(COMPONENT)
ENDIF(NOT CMAKE_INSTALL_COMPONENT)

# Install shared libraries without execute permission?
IF(NOT DEFINED CMAKE_INSTALL_SO_NO_EXE)
  SET(CMAKE_INSTALL_SO_NO_EXE "1")
ENDIF(NOT DEFINED CMAKE_INSTALL_SO_NO_EXE)

IF(NOT CMAKE_INSTALL_COMPONENT OR "${CMAKE_INSTALL_COMPONENT}" STREQUAL "Unspecified")
  IF(EXISTS "$ENV{DESTDIR}/usr/lib/qt4/plugins/inputmethods/libqtim-ibus.so")
    FILE(RPATH_CHECK
         FILE "$ENV{DESTDIR}/usr/lib/qt4/plugins/inputmethods/libqtim-ibus.so"
         RPATH "")
  ENDIF(EXISTS "$ENV{DESTDIR}/usr/lib/qt4/plugins/inputmethods/libqtim-ibus.so")
  FILE(INSTALL DESTINATION "/usr/lib/qt4/plugins/inputmethods" TYPE MODULE FILES "/home/takahiro/devel/kenya888s-maemocjk/kenya888s-maemocjk/ibus-qt-1.3.0-maemo/qtim/libqtim-ibus.so")
  IF(EXISTS "$ENV{DESTDIR}/usr/lib/qt4/plugins/inputmethods/libqtim-ibus.so")
    FILE(RPATH_REMOVE
         FILE "$ENV{DESTDIR}/usr/lib/qt4/plugins/inputmethods/libqtim-ibus.so")
    IF(CMAKE_INSTALL_DO_STRIP)
      EXECUTE_PROCESS(COMMAND "/scratchbox/compilers/bin/strip" "$ENV{DESTDIR}/usr/lib/qt4/plugins/inputmethods/libqtim-ibus.so")
    ENDIF(CMAKE_INSTALL_DO_STRIP)
  ENDIF(EXISTS "$ENV{DESTDIR}/usr/lib/qt4/plugins/inputmethods/libqtim-ibus.so")
ENDIF(NOT CMAKE_INSTALL_COMPONENT OR "${CMAKE_INSTALL_COMPONENT}" STREQUAL "Unspecified")

==> ibus-qt_1.3.1-1maemo2.tar.gz: ibus-qt-1.3.1/qtim/cmake_install.cmake <==
# Install script for directory: /home/kenya888/devel/kenya888s-maemocjk/ibus-qt-1.3.1-maemo/qtim

# Set the install prefix
IF(NOT DEFINED CMAKE_INSTALL_PREFIX)
  SET(CMAKE_INSTALL_PREFIX "/usr")
ENDIF(NOT DEFINED CMAKE_INSTALL_PREFIX)
STRING(REGEX REPLACE "/$" "" CMAKE_INSTALL_PREFIX "${CMAKE_INSTALL_PREFIX}")

# Set the install configuration name.
IF(NOT DEFINED CMAKE_INSTALL_CONFIG_NAME)
  IF(BUILD_TYPE)
    STRING(REGEX REPLACE "^[^A-Za-z0-9_]+" ""
           CMAKE_INSTALL_CONFIG_NAME "${BUILD_TYPE}")
  ELSE(BUILD_TYPE)
    SET(CMAKE_INSTALL_CONFIG_NAME "")
  ENDIF(BUILD_TYPE)
  MESSAGE(STATUS "Install configuration: \"${CMAKE_INSTALL_CONFIG_NAME}\"")
ENDIF(NOT DEFINED CMAKE_INSTALL_CONFIG_NAME)

# Set the component getting installed.
IF(NOT CMAKE_INSTALL_COMPONENT)
  IF(COMPONENT)
    MESSAGE(STATUS "Install component: \"${COMPONENT}\"")
    SET(CMAKE_INSTALL_COMPONENT "${COMPONENT}")
  ELSE(COMPONENT)
    SET(CMAKE_INSTALL_COMPONENT)
  ENDIF(COMPONENT)
ENDIF(NOT CMAKE_INSTALL_COMPONENT)

# Install shared libraries without execute permission?
IF(NOT DEFINED CMAKE_INSTALL_SO_NO_EXE)
  SET(CMAKE_INSTALL_SO_NO_EXE "1")
ENDIF(NOT DEFINED CMAKE_INSTALL_SO_NO_EXE)

IF(NOT CMAKE_INSTALL_COMPONENT OR "${CMAKE_INSTALL_COMPONENT}" STREQUAL "Unspecified")
  IF(EXISTS "$ENV{DESTDIR}/usr/lib/qt4/plugins/inputmethods/libqtim-ibus.so")
    FILE(RPATH_CHECK
         FILE "$ENV{DESTDIR}/usr/lib/qt4/plugins/inputmethods/libqtim-ibus.so"
         RPATH "")
  ENDIF(EXISTS "$ENV{DESTDIR}/usr/lib/qt4/plugins/inputmethods/libqtim-ibus.so")
  FILE(INSTALL DESTINATION "/usr/lib/qt4/plugins/inputmethods" TYPE MODULE FILES "/home/kenya888/devel/kenya888s-maemocjk/ibus-qt-1.3.1-maemo/qtim/libqtim-ibus.so")
  IF(EXISTS "$ENV{DESTDIR}/usr/lib/qt4/plugins/inputmethods/libqtim-ibus.so")
    FILE(RPATH_REMOVE
         FILE "$ENV{DESTDIR}/usr/lib/qt4/plugins/inputmethods/libqtim-ibus.so")
    IF(CMAKE_INSTALL_DO_STRIP)
      EXECUTE_PROCESS(COMMAND "/scratchbox/compilers/bin/strip" "$ENV{DESTDIR}/usr/lib/qt4/plugins/inputmethods/libqtim-ibus.so")
    ENDIF(CMAKE_INSTALL_DO_STRIP)
  ENDIF(EXISTS "$ENV{DESTDIR}/usr/lib/qt4/plugins/inputmethods/libqtim-ibus.so")
ENDIF(NOT CMAKE_INSTALL_COMPONENT OR "${CMAKE_INSTALL_COMPONENT}" STREQUAL "Unspecified")
